@@ -8,3 +8,5 @@ from __future__ import absolute_import, division, print_function
 from .fetch_unpack import fetch_url, unpack_archive
 from .freeze_layers import freeze_leaf_layers
 from .learn_scheduler import create_one_cycle_lr_scheduler
+from .model_regularization import add_dense_layer_loss, add_model_loss
+from .sequence_utils import iob_seq
